︠5e4c1d7a-d797-4e3e-a64d-834bb3511cf6i︠
%html
<h2>Surface Integrals</h2>
<p>Here, we are computing</p>
<p>&nbsp;&nbsp; &nbsp;$\iint_S f(x,y,z)\, d\sigma$</p>
<p>where $f$ is a scalar function, as in Exercises 6, 7, 8, 9, 13, 14 and 34 of Section 13.7 of the Stewart book ``Essential Calculus: Early Transcendentals."</p>
<p>First, we identify the integrand and the surface. &nbsp;The specific $f$ and surface used in the cell below are appropriate for Exercise 5, Section 13.7. &nbsp;Note that I have used $u$ and $v$ as parameters for the surface.</p>

︡66396334-f975-4389-8e13-046aab937f1f︡{"html": "<h2>Surface Integrals</h2>\n<p>Here, we are computing</p>\n<p>&nbsp;&nbsp; &nbsp;$\\iint_S f(x,y,z)\\, d\\sigma$</p>\n<p>where $f$ is a scalar function, as in Exercises 6, 7, 8, 9, 13, 14 and 34 of Section 13.7 of the Stewart book ``Essential Calculus: Early Transcendentals.\"</p>\n<p>First, we identify the integrand and the surface. &nbsp;The specific $f$ and surface used in the cell below are appropriate for Exercise 5, Section 13.7. &nbsp;Note that I have used $u$ and $v$ as parameters for the surface.</p>"}︡
︠b117434b-0ab3-42db-85e3-9c6fe21c67f3︠
var('x y z u v')
f(x,y,z) = y*z
r = vector([u^2, u*sin(v), u*cos(v)])
f_times_dsigma(v,u) = f(*r) * diff(r,u).cross_product(diff(r,v)).norm()
︡11b423da-df64-4219-8fa7-a4ba7083c204︡︡
︠d5967efc-4f9e-49ba-94e9-e719502615f7i︠
%html
<p>If it is possible to compute the surface integral exactly, commands like those of the next cell (which relies on definitions made in the previous one) should do so.</p>

︡8b260b40-39f2-4f0a-8223-38b6c9ee31ea︡{"html": "<p>If it is possible to compute the surface integral exactly, commands like those of the next cell (which relies on definitions made in the previous one) should do so.</p>"}︡
︠ba71efe6-420b-46d3-8d21-925a0210e71d︠
startu = 0; endu = 1
a(u) = 0; b(u) = pi/2
innerint(u) = integral(f_times_dsigma(v,u), v, a, b)
integral(innerint(u), u, startu, endu)
︡c1b7e95f-6597-49a9-b047-136846d5a42f︡{"stdout": "5/48*sqrt(5) + 1/240"}︡
︠bbc1e674-0f1f-4947-9f16-56048f483f87i︠
%html
<p>Alternately, one might compute the integral numerically. &nbsp;In fact, when antiderivatives are not to be found, this is how one must carry out an integral. &nbsp;The next cell is one way to compute our surface integral numerically.</p>

︡2b82e216-510e-48d1-9d3f-362cd8b8be5a︡{"html": "<p>Alternately, one might compute the integral numerically. &nbsp;In fact, when antiderivatives are not to be found, this is how one must carry out an integral. &nbsp;The next cell is one way to compute our surface integral numerically.</p>"}︡
︠3e35a08e-8c53-4530-8eb6-f02114115a7e︠
import scipy
from scipy import integrate
a(u) = 0; b(u) = pi/2
integrate.dblquad(f_times_dsigma, 0, 1, a, b)[0]
︡6744b82f-a67e-4694-8fde-979621db1ecf︡{"stdout": "0.23709041432289477"}︡
︠2527d3a8-f8a8-409a-b167-24315ff40186i︠
%html
<p>Let us summarize the quantities which must be given or found during the computation of the surface integral. &nbsp;You need not pay attention to the commands in the next cell. &nbsp;However, if you make changes to the integrand and/or surface, you can re-execute it so as to update the results in the table it produces.</p>

︡d0c7f180-f01d-4753-89c1-6dec52e2a7b1︡{"html": "<p>Let us summarize the quantities which must be given or found during the computation of the surface integral. &nbsp;You need not pay attention to the commands in the next cell. &nbsp;However, if you make changes to the integrand and/or surface, you can re-execute it so as to update the results in the table it produces.</p>"}︡
︠e40b920d-921b-4003-ac20-7c52465dc0d6︠
from sage.misc.html import math_parse as mp

html.table([
[mp(r" $f(x,y,z)$"), f(x,y,z)],
[mp(r" ${\mathbf r}(u,v)$"), r],
[mp(r" $f({\mathbf r}(u,v))$"), f(*r)],
[mp(r" ${\mathbf r}_u\times {\mathbf r}_v$"), diff(r,u).cross_product(diff(r,v))],
[mp(r" $|{\mathbf r}_u\times {\mathbf r}_v|$"), diff(r,u).cross_product(diff(r,v)).norm()],
[mp(r" $f({\mathbf r}(u,v)) |{\mathbf r}_u\times {\mathbf r}_v|$"), f(*r)*diff(r,u).cross_product(diff(r,v)).norm()]
])
︡6568bf6b-a650-4a9a-b0a2-0f297f473981︡{"html": "\n<div class=\"notruncate\">\n<table class=\"table_form\">\n<tbody>\n<tr class =\"row-a\">\n<td> <span class=\"math\">f(x,y,z)</span></td>\n<td><span class=\"math\">y z</span></td>\n</tr>\n<tr class =\"row-b\">\n<td> <span class=\"math\">{\\mathbf r}(u,v)</span></td>\n<td><span class=\"math\">\\left(u^{2},u \\sin\\left(v\\right),u \\cos\\left(v\\right)\\right)</span></td>\n</tr>\n<tr class =\"row-a\">\n<td> <span class=\"math\">f({\\mathbf r}(u,v))</span></td>\n<td><span class=\"math\">u^{2} \\sin\\left(v\\right) \\cos\\left(v\\right)</span></td>\n</tr>\n<tr class =\"row-b\">\n<td> <span class=\"math\">{\\mathbf r}_u\\times {\\mathbf r}_v</span></td>\n<td><span class=\"math\">\\left(-u \\sin\\left(v\\right)^{2} - u \\cos\\left(v\\right)^{2},2 \\, u^{2} \\sin\\left(v\\right),2 \\, u^{2} \\cos\\left(v\\right)\\right)</span></td>\n</tr>\n<tr class =\"row-a\">\n<td> <span class=\"math\">|{\\mathbf r}_u\\times {\\mathbf r}_v|</span></td>\n<td><span class=\"math\">\\sqrt{{\\left| -u \\sin\\left(v\\right)^{2} - u \\cos\\left(v\\right)^{2} \\right|}^{2} + {\\left| 2 \\, u^{2} \\sin\\left(v\\right) \\right|}^{2} + {\\left| 2 \\, u^{2} \\cos\\left(v\\right) \\right|}^{2}}</span></td>\n</tr>\n<tr class =\"row-b\">\n<td> <span class=\"math\">f({\\mathbf r}(u,v)) |{\\mathbf r}_u\\times {\\mathbf r}_v|</span></td>\n<td><span class=\"math\">\\sqrt{{\\left| -u \\sin\\left(v\\right)^{2} - u \\cos\\left(v\\right)^{2} \\right|}^{2} + {\\left| 2 \\, u^{2} \\sin\\left(v\\right) \\right|}^{2} + {\\left| 2 \\, u^{2} \\cos\\left(v\\right) \\right|}^{2}} u^{2} \\sin\\left(v\\right) \\cos\\left(v\\right)</span></td>\n</tr>\n</tbody>\n</table>\n</div>\n"}︡
︠f5865b4a-ba5f-4e5d-936c-15b1c2811ce2i︠
%html
<h2>Flux across a Surface</h2>
<p>These are <em>special</em> surface integrals taking the form</p>
<p>&nbsp;&nbsp; &nbsp;$\iint_S {\mathbf F} \cdot {\mathbf n}\,d\sigma$.</p>
<p>This type of integral appears in Exercises 19, 20, 22, 25 and 26 of Section 13.7 in the Stewart text ``Essential Calculus: Early Transcentals."</p>
<p>The cells below have been tailored to the specifics of Exercise 21 of Section 13.7.</p>

︡180761ea-16aa-4dd6-a7ab-e3c7bdc2f76b︡{"html": "<h2>Flux across a Surface</h2>\n<p>These are <em>special</em> surface integrals taking the form</p>\n<p>&nbsp;&nbsp; &nbsp;$\\iint_S {\\mathbf F} \\cdot {\\mathbf n}\\,d\\sigma$.</p>\n<p>This type of integral appears in Exercises 19, 20, 22, 25 and 26 of Section 13.7 in the Stewart text ``Essential Calculus: Early Transcentals.\"</p>\n<p>The cells below have been tailored to the specifics of Exercise 21 of Section 13.7.</p>"}︡
︠b7d503aa-71a6-45b6-a5c0-302008d4d8fd︠
var('x y z u v')
F = vector([x*z*exp(y), -x*z*exp(y), z])
r = vector([u, v, 1 - u - v])
full_integrand(v,u) = F(x=r[0], y=r[1], z=r[2]) * diff(r,u).cross_product(diff(r,v))
︡10f34712-9aea-4d38-889d-dfbf1649df15︡︡
︠de6bc4a7-47bf-4050-ab19-c29ae4fef369i︠
%html
<p>If it is possible to find the exact value of the flux integral, the next cell will do so.</p>

︡46e34b22-f671-4445-a0e5-c62afcfb4b21︡{"html": "<p>If it is possible to find the exact value of the flux integral, the next cell will do so.</p>"}︡
︠cca4f463-5fb6-4612-bc70-ed98aab2da8b︠
startu = 0; endu = 1
a(u) = 0; b(u) = 1 - u
innerint(u) = integral(full_integrand(v,u), v, a, b)
integral(innerint(u), u, startu, endu)
︡fab51abf-3121-439b-9892-1af040592335︡{"stdout": "1/6"}︡
︠956ec533-2489-4c5c-a4f6-d57ff19fb874i︠
%html
<p>Whether the value just computed is the correct answer or the negative of it depends on which of the two normals we picked to our surface.</p>
<p>In the next cell, we repeat this calculation using numerical integration (<em>quadrature</em>, as it is called), which should yield answers even when antiderivatives are unavailable. &nbsp;The only downside is not having <em>exact</em> answers.</p>

︡f822edd8-5f29-40cc-b28c-482795a4bcba︡{"html": "<p>Whether the value just computed is the correct answer or the negative of it depends on which of the two normals we picked to our surface.</p>\n<p>In the next cell, we repeat this calculation using numerical integration (<em>quadrature</em>, as it is called), which should yield answers even when antiderivatives are unavailable. &nbsp;The only downside is not having <em>exact</em> answers.</p>"}︡
︠7dfebfc8-546b-403f-b8ba-b151c8d46078︠
import scipy
from scipy import integrate
a(x)=0
b(x)=1-x
integrate.dblquad(full_integrand,0,1,a,b)[0]
︡ac8c3bdb-b999-41d5-b65e-6babfb868f66︡{"stdout": "0.16666666666666669"}︡
︠7717dcc1-de81-4320-8961-b67843810468i︠
%html
<p>The relevant quantities in the integral appear below. &nbsp;They are contingent on your being able to find a valid parametrization of your surface using parameters $u$ and $v$.</p>

︡c759f62c-3cec-4335-91f1-eec346f61c9f︡{"html": "<p>The relevant quantities in the integral appear below. &nbsp;They are contingent on your being able to find a valid parametrization of your surface using parameters $u$ and $v$.</p>"}︡
︠8225130b-0eb2-4395-ae1c-203dbfb47e91︠
from sage.misc.html import math_parse as mp

html.table([
[mp(r" ${\mathbf F}(x,y,z)$"), F],
[mp(r" ${\mathbf r}(u,v)$"), r],
[mp(r" ${\mathbf F}({\mathbf r}(u,v))$"), F(x=r[0], y=r[1], z=r[2])],
[mp(r" ${\mathbf r}_u\times {\mathbf r}_v$"), diff(r,u).cross_product(diff(r,v))],
[mp(r" ${\mathbf F}({\mathbf r}(u,v)) \cdot ({\mathbf r}_u\times {\mathbf r}_v)$"), F(x=r[0], y=r[1], z=r[2])*diff(r,u).cross_product(diff(r,v))]
])
︡dca83cc2-7cd9-42d7-92af-06be02a7dfdb︡{"html": "\n<div class=\"notruncate\">\n<table class=\"table_form\">\n<tbody>\n<tr class =\"row-a\">\n<td> <span class=\"math\">{\\mathbf F}(x,y,z)</span></td>\n<td><span class=\"math\">\\left(x z e^{y},-x z e^{y},z\\right)</span></td>\n</tr>\n<tr class =\"row-b\">\n<td> <span class=\"math\">{\\mathbf r}(u,v)</span></td>\n<td><span class=\"math\">\\left(u,v,-u - v + 1\\right)</span></td>\n</tr>\n<tr class =\"row-a\">\n<td> <span class=\"math\">{\\mathbf F}({\\mathbf r}(u,v))</span></td>\n<td><span class=\"math\">\\left(-{\\left(u + v - 1\\right)} u e^{v},{\\left(u + v - 1\\right)} u e^{v},-u - v + 1\\right)</span></td>\n</tr>\n<tr class =\"row-b\">\n<td> <span class=\"math\">{\\mathbf r}_u\\times {\\mathbf r}_v</span></td>\n<td><span class=\"math\">\\left(1,1,1\\right)</span></td>\n</tr>\n<tr class =\"row-a\">\n<td> <span class=\"math\">{\\mathbf F}({\\mathbf r}(u,v)) \\cdot ({\\mathbf r}_u\\times {\\mathbf r}_v)</span></td>\n<td><span class=\"math\">-u - v + 1</span></td>\n</tr>\n</tbody>\n</table>\n</div>\n"}︡
